==> qxmledit-0.8.5-src.tgz: qxmledit-0.8.5/src/snippet_interface.h <==
/**************************************************************************
 *  This file is part of QXmlEdit                                         *
 *  Copyright (C) 2011 by Luca Bellonda and individual contributors       *
 *    as indicated in the AUTHORS file                                    *
 *  lbellonda _at_ gmail.com                                              *
 *                                                                        *
 * This library is free software; you can redistribute it and/or          *
 * modify it under the terms of the GNU Library General Public            *
 * License as published by the Free Software Foundation; either           *
 * version 2 of the License, or (at your option) any later version.       *
 *                                                                        *
 * This library is distributed in the hope that it will be useful,        *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of         *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU      *
 * Library General Public License for more details.                       *
 *                                                                        *
 * You should have received a copy of the GNU Library General Public      *
 * License along with this library; if not, write to the                  *
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,       *
 * Boston, MA  02110-1301  USA                                            *
 **************************************************************************/
#ifndef SNIPPET_INTERFACE_H
#define SNIPPET_INTERFACE_H

#include "regola.h"

void editSnippets(ApplicationData *data, QWidget *parent);

Regola* chooseSnippets(ApplicationData *data, QWidget *parent);

void insertFragmentInSnippets(QWidget *parent, ApplicationData *data, const QString &text);

#endif // SNIPPET_INTERFACE_H

==> qxmledit-0.9.9.2-src.tgz: qxmledit-0.9.9.2/src/snippet_interface.h <==
/**************************************************************************
 *  This file is part of QXmlEdit                                         *
 *  Copyright (C) 2011 by Luca Bellonda and individual contributors       *
 *    as indicated in the AUTHORS file                                    *
 *  lbellonda _at_ gmail.com                                              *
 *                                                                        *
 * This library is free software; you can redistribute it and/or          *
 * modify it under the terms of the GNU Library General Public            *
 * License as published by the Free Software Foundation; either           *
 * version 2 of the License, or (at your option) any later version.       *
 *                                                                        *
 * This library is distributed in the hope that it will be useful,        *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of         *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU      *
 * Library General Public License for more details.                       *
 *                                                                        *
 * You should have received a copy of the GNU Library General Public      *
 * License along with this library; if not, write to the                  *
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,       *
 * Boston, MA  02110-1301  USA                                            *
 **************************************************************************/
#ifndef SNIPPET_INTERFACE_H
#define SNIPPET_INTERFACE_H

#include "regola.h"

class SnippetManager
{
public:
    SnippetManager();
    virtual ~SnippetManager();
    virtual void editSnippets(ApplicationData *data, QWidget *parent);

    virtual Regola* chooseSnippets(ApplicationData *data, QWidget *parent);

    virtual void insertFragmentInSnippets(QWidget *parent, ApplicationData *data, const QString &text);
};

#endif // SNIPPET_INTERFACE_H
